@@ -1,4 +1,4 @@
-package Dist::Zilla::Plugin::Author::Plicease::Cleaner 2.74 {
+package Dist::Zilla::Plugin::Author::Plicease::Cleaner 2.75 {
 
   use 5.020;
   use Moose;
@@ -18,7 +18,13 @@ package Dist::Zilla::Plugin::Author::Plicease::Cleaner 2.74 {
     default => sub { [] },
   );
 
-  sub mvp_multivalue_args { qw( clean ) }
+  has clean_keep => (
+    is      => 'ro',
+    isa     => 'ArrayRef[Str]',
+    default => sub { [] },
+  );
+
+  sub mvp_multivalue_args { qw( clean clean_keep ) }
 
   sub BUILD ($self, $) {
 
@@ -75,6 +81,11 @@ package Dist::Zilla::Plugin::Author::Plicease::Cleaner 2.74 {
 
     sub remove_file_or_dir ($self, $path, $dry)
     {
+      foreach my $keep ($self->clean_keep->@*)
+      {
+        return if $path =~ /$keep/;
+      }
+
       if($dry)
       {
         $self->log("clean: would remove $path");
@@ -117,7 +128,7 @@ Dist::Zilla::Plugin::Author::Plicease::Cleaner - Clean things up
 
 =head1 VERSION
 
-version 2.74
+version 2.75
 
 =head1 SYNOPSIS
 
